@@ -1,4 +1,23 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/*
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
+ *
+ * Authors:
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
+ *
+ */
 
 #include <config.h>
 #include <string.h>
@@ -133,7 +152,7 @@ e_contact_list_model_add_email (EContactListModel *model,
 	g_return_if_fail (email != NULL);
 
 	if (e_contact_list_model_has_email (model, email))
-		if (e_error_run (NULL, tag, email) != GTK_RESPONSE_YES)
+		if (e_error_run (NULL, tag, email, NULL) != GTK_RESPONSE_YES)
 			return;
 
 	destination = e_destination_new ();
