@@ -27,7 +27,7 @@
 #endif
 
 #include <string.h>
-#include <gtk/gtksignal.h>
+#include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
 #include <libgnomecanvas/gnome-canvas-rect-ellipse.h>
