@@ -1124,7 +1124,7 @@ em_format_format_text(EMFormat *emf, CamelStream *stream, CamelDataWrapper *dw)
 	camel_object_unref(filter_stream);
 	camel_stream_reset (mem_stream);
 
-	if (max == -1 || size < (max * 1024) || emf->composer) {
+	if (max == -1 || size == -1 || size < (max * 1024) || emf->composer) {
 		camel_stream_write_to_stream(mem_stream, (CamelStream *)stream);
 		camel_stream_flush((CamelStream *)stream);
 	} else {
@@ -1653,6 +1653,8 @@ emf_inlinepgp_encrypted(EMFormat *emf, CamelStream *stream, CamelMimePart *ipart
 	CamelCipherValidity *valid;
 	CamelException *ex;
 	CamelMimePart *opart;
+	CamelDataWrapper *dw;
+	char *mime_type;
 
 	cipher = camel_gpg_context_new(emf->session);
 	ex = camel_exception_new();
@@ -1671,6 +1673,19 @@ emf_inlinepgp_encrypted(EMFormat *emf, CamelStream *stream, CamelMimePart *ipart
 		return;
 	}
 
+	dw = camel_medium_get_content_object ((CamelMedium *)opart);
+	mime_type = camel_data_wrapper_get_mime_type (dw);
+
+	/* this ensures to show the 'opart' as inlined, if possible */
+	if (mime_type && g_ascii_strcasecmp (mime_type, "application/octet-stream") == 0) {
+		const char *snoop = em_utils_snoop_type (opart);
+
+		if (snoop)
+			camel_data_wrapper_set_mime_type (dw, snoop);
+	}
+
+	g_free (mime_type);
+
 	/* Pass it off to the real formatter */
 	em_format_format_secure(emf, stream, opart, valid);
 
